##########
fontbureau
##########

All vendor-specific profiles such as the `fontbureau` one also include the checks from the :doc:`universal` profile.

.. automodule:: fontbakery.profiles.fontbureau
   :members:
   :undoc-members:
